<!DOCTYPE html>

{% load static %}

<html lang="en">
  <head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">

    <title>{% block title %}System Maintenance{% endblock %}</title>

    <link href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.4/css/bootstrap.min.css" rel="stylesheet" integrity="sha256-8EtRe6XWoFEEhWiaPkLawAD1FkD9cbmGgEy6F46uQqU= sha512-/5KWJw2mvMO2ZM5fndVxUQmpVPqaxZyYRTMrXtrprsyQ2zM0o0NMjU02I8ZJXeBPtrmrPO4IAyCCRsydG0BJoQ==" crossorigin="anonymous">
    <link rel="stylesheet" type="text/css" href="{% static 'system_maintenance/css/app.css' %}">
    <link rel="stylesheet" type="text/css" href="{% static 'system_maintenance/css/syntax-highlighting.css' %}">

    <!-- HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries -->
    <!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
    <!--[if lt IE 9]>
      <script src="https://oss.maxcdn.com/html5shiv/3.7.2/html5shiv.min.js"></script>
      <script src="https://oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>
    <![endif]-->
  </head>

  <body>
    {% block content %}{% endblock %}
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/1.11.3/jquery.min.js"></script>
    <script src="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.4/js/bootstrap.min.js" integrity="sha256-1f0XPQDZczkAg04OEIPehrUy4EixXAQgulwtsGI2RLg= sha512-4YpZWXNqnO72e0Da95ZMUZxnjWgLvajSx2eSgfXTSaKGyZuWyiTnqOZM6YfTctdK4S2nJVxgbM/iesE6NbWj0g==" crossorigin="anonymous"></script>
    <script src="{% static 'system_maintenance/js/app.js' %}"></script>
  </body>
</html>
